/* eslint-disable @next/next/no-img-element */
import '~/styles/globals.css';
import { Heebo } from 'next/font/google';
import { type Metadata } from 'next';
import Script from 'next/script';

import { ThemeProvider } from '~/components/theme-provider';
import { ModeToggle } from '~/components/theme-toggle';
import { cn } from '~/lib/utils';
import { env } from '~/env';

export const metadata: Metadata = {
  title: 'Primo Dental Clinic',
  description:
    'Cerchi una Clinica Dentale affidabile? Primo Dental Clinic offre trattamenti dentali di qualità a Tirana, Albania.',
  icons: [{ rel: 'icon', url: '/Primo-Logo.webp' }],
};

const heebo = Heebo({
  subsets: ['latin'], // use other subsets if necessary
  weight: ['400', '500', '700'], // specify font weights you want
});

export default function RootLayout({ children }: Readonly<{ children: React.ReactNode }>) {
  return (
    <html lang='en'>
      <head>
        <Script
          async
          src={`https://www.googletagmanager.com/gtag/js?id=${env.GOOGLE_ANALYTICS_KEY}`}
        ></Script>
        <Script id='google-analytics'>
          {`window.dataLayer = window.dataLayer || [];
        function gtag(){dataLayer.push(arguments);}
        gtag('js', new Date());

        gtag('config', ${env.GOOGLE_ANALYTICS_KEY});`}
        </Script>
        <Script id='facebook-pixel' strategy='afterInteractive'>
          {`
            !function(f,b,e,v,n,t,s)
            {if(f.fbq)return;n=f.fbq=function(){n.callMethod?
            n.callMethod.apply(n,arguments):n.queue.push(arguments)};
            if(!f._fbq)f._fbq=n;n.push=n;n.loaded=!0;n.version='2.0';
            n.queue=[];t=b.createElement(e);t.async=!0;
            t.src=v;s=b.getElementsByTagName(e)[0];
            s.parentNode.insertBefore(t,s)}(window, document,'script',
            'https://connect.facebook.net/en_US/fbevents.js');
            fbq('init', '${env.META_PIXEL_ID}');
            fbq('track', 'PageView');
          `}
        </Script>
        <noscript>
          <img
            height='1'
            width='1'
            style={{ display: 'none' }}
            src={`https://www.facebook.com/tr?id=${env.META_PIXEL_ID}&ev=PageView&noscript=1`}
            alt=''
          />
        </noscript>
      </head>
      <body className={cn(heebo.className, 'min-h-screen bg-background antialiased')}>
        <ThemeProvider
          attribute='class'
          defaultTheme='system'
          enableSystem
          disableTransitionOnChange
        >
          <ModeToggle />
          <main className='relative flex h-screen flex-col'>
            <div className='w-full flex-grow'>{children}</div>
          </main>
        </ThemeProvider>
      </body>
    </html>
  );
}
